@@ -1,13 +1,13 @@
 package CGI::Session;
 
-# $Id: /local/cgi-session/trunk/lib/CGI/Session.pm 297 2006-03-16T02:27:26.386605Z mark  $
+# $Id: Session.pm 259 2006-03-16 22:11:02Z markstos $
 
 use strict;
 use Carp;
 use CGI::Session::ErrorHandler;
 
 @CGI::Session::ISA      = qw( CGI::Session::ErrorHandler );
-$CGI::Session::VERSION  = '4.08';
+$CGI::Session::VERSION  = '4.09';
 $CGI::Session::NAME     = 'CGISESSID';
 $CGI::Session::IP_MATCH = 0;
 
@@ -131,9 +131,8 @@ sub query {
     if ( $self->{_QUERY} ) {
         return $self->{_QUERY};
     }
-    require CGI;
-    $self->{_QUERY} = CGI->new();
-    return $self->{_QUERY};
+    require CGI::Session::Query;
+    return $self->{_QUERY} = CGI::Session::Query->new();
 }
 
 
@@ -285,7 +284,7 @@ sub delete {    $_[0]->_set_status( STATUS_DELETED )    }
 my $avoid_single_use_warning_again = *header;
 sub http_header {
     my $self = shift;
-    return $self->query->header(-cookie=>$self->cookie, type=>'text/html', @_);
+    return $self->query->header(-cookie=>$self->cookie, -type=>'text/html', @_);
 }
 
 sub cookie {
@@ -296,12 +295,13 @@ sub cookie {
 
     if ( $self->is_expired ) {
         $cookie = $query->cookie( -name=>$self->name, -value=>$self->id, -expires=> '-1d', @_ );
-    } elsif ( my $t = $self->expire ) {
+    } 
+    elsif ( my $t = $self->expire ) {
         $cookie = $query->cookie( -name=>$self->name, -value=>$self->id, -expires=> $t . 's', @_ );
-    } else {
+    } 
+    else {
         $cookie = $query->cookie( -name=>$self->name, -value=>$self->id, @_ );
     }
-
     return $cookie;
 }
 
@@ -405,7 +405,7 @@ sub find {
     return 1;
 }
 
-# $Id: /local/cgi-session/trunk/lib/CGI/Session.pm 297 2006-03-16T02:27:26.386605Z mark  $
+# $Id: Session.pm 259 2006-03-16 22:11:02Z markstos $
 
 =pod
 
